##  Visualizing Relations
In matrix reports, using organization and business context fact sheets as the two dimensions, you can see:
  * Which applications support a specific process across all organizations
  * Which applications support a specific process in specific organizational units
  * You can also filter the report by a specific organization to see the process-application relations.
